PYPIPR = True

"""PYPIPR Module"""

"""PYTHON Standard Module"""

"""PYPI Module"""


class Pypipr:
    @staticmethod
    def test_print():
        """Print simple text to test this module is working"""
        print("Hello from PyPIPr")
